@@ -2,16 +2,11 @@
 # https://docs.djangoproject.com/en/3.2/topics/testing/advanced/#using-the-django-test-runner-to-test-reusable-applications
 
 import os
-import sys
 
 import django
-from django.conf import settings
-from django.test.utils import get_runner
+from django.core.management import call_command
 
 if __name__ == "__main__":
     os.environ['DJANGO_SETTINGS_MODULE'] = 'tests.test_settings'
     django.setup()
-    TestRunner = get_runner(settings)
-    test_runner = TestRunner()
-    failures = test_runner.run_tests(["tests"])
-    sys.exit(bool(failures))
+    call_command("test", interactive=False)
